<?php
/**
 * IML APPMONITOR CHECKS FOR CI SERVER
 * 
 * @author: Axel Hahn
 * 
 * ------------------------------------------------------------------
 * 2025-01-06  initial version
 */

require_once('classes/appmonitor-client.class.php');

$aAppDefaults = [
    "df" => [
        "warning" => "1GB",
        "critical" => "100MB"
    ]
];

$oMonitor = new appmonitor();

$sWebroot = dirname(__DIR__);

include('general_include.php');

$sCfgfile="$sWebroot/inc_config.php";
$aConfig=require_once $sCfgfile;

$oMonitor->addTag('ci-pkg');
$oMonitor->addTag('rollout');

if(isset($aConfig['monitor-ips']) && is_array($aConfig['monitor-ips']) && count($aConfig['monitor-ips']) > 0) {    
    $oMonitor->checkIp($aConfig['monitor-ips']);
}


// ----------------------------------------------------------------------
// config file
// ----------------------------------------------------------------------

$oMonitor->addCheck(
    [
        "name" => "read config file",
        "description" => "Check if config file is readable",
        "check" => [
            "function" => "File",
            "params" => [
                "filename" => $sCfgfile,
                "file"     => true,
                "readable" => true,
            ],
        ],
    ]
);

// ----------------------------------------------------------------------
// api and hash data
// ----------------------------------------------------------------------

$oMonitor->addCheck(
    [
        "name" => "check api dir",
        "description" => "Check if api dir is readable and writable",
        "parent" => "read config file",
        "check" => [
            "function" => "File",
            "params" => [
                "filename" => $aConfig['tmpdir'],
                "dir"     => true,
                "readable" => true,
                "writable" => true,
            ],
        ],
    ]
);

if (file_exists($aConfig['tmpdir'] . "/used_hashes.txt")) {
    $oMonitor->addCheck(
        [
            "name" => "write hashes file",
            "description" => "Check if hashes file is writable",
            "parent" => "check api dir",
            "check" => [
                "function" => "File",
                "params" => [
                    "filename" => $aConfig['tmpdir'] . "/used_hashes.txt",
                    "file"     => true,
                    "readable" => true,
                    "writable" => true,
                ],
            ],
        ]
    );
}

$oMonitor->addCheck(
    [
        "name" => "diskspace api dir",
        "description" => "The file storage must have some space left",
        "parent" => "check api dir",
        "check" => [
            "function" => "Diskfree",
            "params" => [
                "directory" => $aConfig['tmpdir'],
                "warning"   => "5MB",
                "critical"  => "100KB",
            ],
        ],
    ]
);

// ----------------------------------------------------------------------
// packages dir
// ----------------------------------------------------------------------

$oMonitor->addCheck(
    [
        "name" => "check package dir",
        "description" => "Check if package dir is readable",
        "parent" => "read config file",
        "check" => [
            "function" => "File",
            "params" => [
                "filename" => $aConfig['packagedir'],
                "dir"     => true,
                "readable" => true,
            ],
        ],
    ]
);

$oMonitor->addCheck(
    [
        "name" => "diskspace package dir",
        "description" => "The file storage must have some space left - warn: " . $aAppDefaults["df"]['warning'] . "/ critical: " . $aAppDefaults["df"]['critical'],
        "parent" => "check package dir",
        "check" => [
            "function" => "Diskfree",
            "params" => [
                "directory" => $aConfig['packagedir'],
                "warning"   => $aAppDefaults["df"]['warning'],
                "critical"  => $aAppDefaults["df"]['critical'],
            ],
        ],
    ]
);

// ----------------------------------------------------------------------
// system stuff
// ----------------------------------------------------------------------

require 'plugins/apps/shared_check_ssl.php';

// ----------------------------------------------------------------------

$oMonitor->setResult();
$oMonitor->render();

// ----------------------------------------------------------------------
